Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AssistantRuntime ¶
type AssistantRuntime struct {
Soul assistant.AssistantSoul
MemoryManager memory.MemoryManager
Planner planner.ExecutionPlanner
ToolRunner toolrunner.ToolRunner
ModelProvider llm.ModelProvider
}
AssistantRuntime encapsulates the entire AI Assistant execution loop.
func NewAssistantRuntime ¶
func NewAssistantRuntime(cfg Config) (*AssistantRuntime, error)
NewAssistantRuntime initializes the system and loads the soul layout.
func (*AssistantRuntime) ProcessChat ¶
func (r *AssistantRuntime) ProcessChat(ctx context.Context, sessionID, message string) (<-chan string, error)
ProcessChat represents the full runtime loop for a user request.
type Config ¶
type Config struct {
SoulPath string
MemoryManager memory.MemoryManager
Planner planner.ExecutionPlanner
ToolRunner toolrunner.ToolRunner
ModelProvider llm.ModelProvider
}
Config holds components required to scaffold the runtime.
Click to show internal directories.
Click to hide internal directories.